==> cordova-custom-config-1.1.9.tgz: package/hooks/logger.js <==
#!/usr/bin/env node

var logger = (function(){

    /**********************
     * Internal properties
     *********************/
    var logger, context;

    try{
        require('colors');
    }catch(e){}

    function prefixMsg(msg){
        return context.opts.plugin.id+": "+msg;
    }

    /************
     * Public API
     ************/
    logger = {
        init: function(ctx){
            context = ctx;
        },
        debug: function(msg){
            if(context.opts.verbose){
                msg = prefixMsg(msg);
                try{
                    console.log(msg.green);
                }catch(e){
                    console.log(msg);
                }
            }
        },
        log: function(msg){
            msg = prefixMsg(msg);
            try{
                console.log(msg.white);
            }catch(e){
                console.log(msg);
            }
        },
        info: function(msg){
            msg = prefixMsg(msg);
            try{
                console.log(msg.blue);
            }catch(e){
                console.info(msg);
            }
        },
        warn: function(msg){
            msg = prefixMsg(msg);
            try{
                console.log(msg.yellow);
            }catch(e){
                console.warn(msg);
            }
        },
        error: function(msg){
            msg = prefixMsg(msg);
            try{
                console.log(msg.red);
            }catch(e){
                console.error(msg);
            }
        }
    };
    return logger;
})();

module.exports = function(ctx){
    logger.init(ctx);
    return logger;
};

==> cordova-custom-config-1.2.0.tgz: package/hooks/logger.js <==
#!/usr/bin/env node

var logger = (function(){

    /**********************
     * Internal properties
     *********************/
    var logger, context, hasColors = true;

    try{
        require('colors');
    }catch(e){
        hasColors = false;
    }

    function prefixMsg(msg){
        return context.opts.plugin.id+": "+msg;
    }

    /************
     * Public API
     ************/
    logger = {
        init: function(ctx){
            context = ctx;
        },
        debug: function(msg){
            if(context.opts.verbose){
                msg = prefixMsg(msg);
                if(hasColors){
                    console.log(msg.green);
                }else{
                    console.log(msg);
                }
            }
        },
        log: function(msg){
            msg = prefixMsg(msg);
            if(hasColors){
                console.log(msg.white);
            }else{
                console.log(msg);
            }
        },
        info: function(msg){
            msg = prefixMsg(msg);
            if(hasColors){
                console.log(msg.blue);
            }else{
                console.info(msg);
            }
        },
        warn: function(msg){
            msg = prefixMsg(msg);
            if(hasColors){
                console.log(msg.yellow);
            }else{
                console.warn(msg);
            }
        },
        error: function(msg){
            msg = prefixMsg(msg);
            if(hasColors){
                console.log(msg.red);
            }else{
                console.error(msg);
            }
        }
    };
    return logger;
})();

module.exports = function(ctx){
    logger.init(ctx);
    return logger;
};
